/*
 * Event debug function
 *
 * Authors:
 * Copyright 2012 by Maciej Jaros <egil@wp.pl>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * Otherwise use it as you wish. It is my hope that it will be for good not evil. :-)
 */

/**
	Print event info to stderr
	
	Codes can be found at:
	http://lxr.free-electrons.com/source/include/linux/input.h
*/
void debug_event_info (struct input_event *ievent)
{
	// fill type and code buffer
	int type = ievent->type;
	int code = ievent->code;
	char type_buffer[10];
	char code_buffer[100];
	switch (type)
	{
		case EV_SYN      : strcpy(type_buffer, "SYN"); break;
		case EV_KEY      : strcpy(type_buffer, "KEY"); break;
		case EV_REL      : strcpy(type_buffer, "REL"); break;
		case EV_ABS      : strcpy(type_buffer, "ABS"); break;
		case EV_MSC      : strcpy(type_buffer, "MSC"); break;
		case EV_SW       : strcpy(type_buffer, "SW "); break;
		case EV_LED      : strcpy(type_buffer, "LED"); break;
		case EV_SND      : strcpy(type_buffer, "SND"); break;
		case EV_REP      : strcpy(type_buffer, "REP"); break;
		case EV_FF       : strcpy(type_buffer, "FF "); break;
		case EV_PWR      : strcpy(type_buffer, "PWR"); break;
		case EV_FF_STATUS: strcpy(type_buffer, "FFS"); break;
		case EV_MAX      : strcpy(type_buffer, "MAX"); break;
		case EV_CNT      : strcpy(type_buffer, "CNT"); break;
		default: sprintf(type_buffer, "%d", type); break;
	}

	if (type == EV_SYN)
	{
		switch (code)
		{
			case SYN_REPORT    : strcpy(code_buffer, "REPORT   "); break;
			case SYN_CONFIG    : strcpy(code_buffer, "CONFIG   "); break;
			case SYN_MT_REPORT : strcpy(code_buffer, "MT_REPORT"); break;
			// not avialable in scratchbox with HARMETTAN_ARMEL
			//case SYN_DROPPED   : strcpy(code_buffer, "DROPPED  "); break;
			default: sprintf(code_buffer, "%d", code); break;
		}
	}
	else if (type == EV_REL)
	{
		switch (code)
		{
			case REL_X      : strcpy(code_buffer, "X     "); break;
			case REL_Y      : strcpy(code_buffer, "Y     "); break;
			case REL_Z      : strcpy(code_buffer, "Z     "); break;
			case REL_RX     : strcpy(code_buffer, "RX    "); break;
			case REL_RY     : strcpy(code_buffer, "RY    "); break;
			case REL_RZ     : strcpy(code_buffer, "RZ    "); break;
			case REL_HWHEEL : strcpy(code_buffer, "HWHEEL"); break;
			case REL_DIAL   : strcpy(code_buffer, "DIAL  "); break;
			case REL_WHEEL  : strcpy(code_buffer, "WHEEL "); break;
			case REL_MISC   : strcpy(code_buffer, "MISC  "); break;
			case REL_MAX    : strcpy(code_buffer, "MAX   "); break;
			case REL_CNT    : strcpy(code_buffer, "CNT   "); break;
			default: sprintf(code_buffer, "%d", code); break;
		}
	}
	else if (type == EV_ABS)
	{
		switch (code)
		{
			case ABS_X             : strcpy(code_buffer, "X             "); break;
			case ABS_Y             : strcpy(code_buffer, "Y             "); break;
			case ABS_Z             : strcpy(code_buffer, "Z             "); break;
			case ABS_RX            : strcpy(code_buffer, "RX            "); break;
			case ABS_RY            : strcpy(code_buffer, "RY            "); break;
			case ABS_RZ            : strcpy(code_buffer, "RZ            "); break;
			case ABS_THROTTLE      : strcpy(code_buffer, "THROTTLE      "); break;
			case ABS_RUDDER        : strcpy(code_buffer, "RUDDER        "); break;
			case ABS_WHEEL         : strcpy(code_buffer, "WHEEL         "); break;
			case ABS_GAS           : strcpy(code_buffer, "GAS           "); break;
			case ABS_BRAKE         : strcpy(code_buffer, "BRAKE         "); break;
			case ABS_HAT0X         : strcpy(code_buffer, "HAT0X         "); break;
			case ABS_HAT0Y         : strcpy(code_buffer, "HAT0Y         "); break;
			case ABS_HAT1X         : strcpy(code_buffer, "HAT1X         "); break;
			case ABS_HAT1Y         : strcpy(code_buffer, "HAT1Y         "); break;
			case ABS_HAT2X         : strcpy(code_buffer, "HAT2X         "); break;
			case ABS_HAT2Y         : strcpy(code_buffer, "HAT2Y         "); break;
			case ABS_HAT3X         : strcpy(code_buffer, "HAT3X         "); break;
			case ABS_HAT3Y         : strcpy(code_buffer, "HAT3Y         "); break;
			case ABS_PRESSURE      : strcpy(code_buffer, "PRESSURE      "); break;
			case ABS_DISTANCE      : strcpy(code_buffer, "DISTANCE      "); break;
			case ABS_TILT_X        : strcpy(code_buffer, "TILT_X        "); break;
			case ABS_TILT_Y        : strcpy(code_buffer, "TILT_Y        "); break;
			case ABS_TOOL_WIDTH    : strcpy(code_buffer, "TOOL_WIDTH    "); break;
			case ABS_VOLUME        : strcpy(code_buffer, "VOLUME        "); break;
			case ABS_MISC          : strcpy(code_buffer, "MISC          "); break;
			//case ABS_MT_SLOT       : strcpy(code_buffer, "MT_SLOT       "); break;
			case ABS_MT_TOUCH_MAJOR: strcpy(code_buffer, "MT_TOUCH_MAJOR"); break;
			case ABS_MT_TOUCH_MINOR: strcpy(code_buffer, "MT_TOUCH_MINOR"); break;
			case ABS_MT_WIDTH_MAJOR: strcpy(code_buffer, "MT_WIDTH_MAJOR"); break;
			case ABS_MT_WIDTH_MINOR: strcpy(code_buffer, "MT_WIDTH_MINOR"); break;
			case ABS_MT_ORIENTATION: strcpy(code_buffer, "MT_ORIENTATION"); break;
			case ABS_MT_POSITION_X : strcpy(code_buffer, "MT_POSITION_X "); break;
			case ABS_MT_POSITION_Y : strcpy(code_buffer, "MT_POSITION_Y "); break;
			case ABS_MT_TOOL_TYPE  : strcpy(code_buffer, "MT_TOOL_TYPE  "); break;
			case ABS_MT_BLOB_ID    : strcpy(code_buffer, "MT_BLOB_ID    "); break;
			case ABS_MT_TRACKING_ID: strcpy(code_buffer, "MT_TRACKING_ID"); break;
			//case ABS_MT_PRESSURE   : strcpy(code_buffer, "MT_PRESSURE   "); break;
			//case ABS_MT_DISTANCE   : strcpy(code_buffer, "MT_DISTANCE   "); break;
			//case ABS_MT_TOOL_X     : strcpy(code_buffer, "MT_TOOL_X     "); break;
			//case ABS_MT_TOOL_Y     : strcpy(code_buffer, "MT_TOOL_Y     "); break;
			case ABS_MAX           : strcpy(code_buffer, "MAX           "); break;
			case ABS_CNT           : strcpy(code_buffer, "CNT           "); break;
			default: sprintf(code_buffer, "%d", code); break;
		}
	}
	else
	{
		sprintf(code_buffer, "%d", code);
	}

	// -----------------------
	// format and print output
	fprintf(stderr, "\n%10.5f: [%s:%s] = %d", 
		(double) ievent->time.tv_sec + (double) ievent->time.tv_usec / 1000000.0,
		type_buffer,
		code_buffer,
		ievent->value
	);
}
